/*****************************************************************************/
/*
                                   Net.h

Function prototypes for TCP/IP networking module.

*/
/*****************************************************************************/

/* Internet-related header files */
#ifdef IP_UCX
#   include <socket.h>
#   include <in.h>
#   include <netdb.h>
#   include <inet.h>
#   include <ucx$inetdef.h>
#endif

#ifdef IP_NETLIB
#   include "netlibdef.h"
#endif

/*********************/
/* service structure */
/*********************/

struct ServiceStruct
{
   struct ServiceStruct  *NextPtr;

   int  ConnectCount,
        RequestScheme,
        ServerHostNameLength,
        ServerPort;
   unsigned long  ClientInternetAddress32bit,
                  ServerInternetAddress32bit;
   char  *RequestSchemeNamePtr;
   char  ClientHostName [128],
         ClientInternetAddress [32],
         ServerHostName [128],
         ServerHostPort [128],
         ServerInternetAddress [32],
         ServerPortString [16];
   struct AnIOsb  ServerIOsb;
   
#ifdef IP_UCX

   unsigned short  ClientChannel,
                   ServerChannel;

   struct sockaddr_in  ServerSocketName,
                       ClientSocketName;

   struct hostent  *HostEntryPtr;

   struct {
      unsigned int  Length;
      char  *Address;
   } ServerSocketNameItem;

   int  ClientSocketNameLength;
   struct {
      unsigned int  Length;
      char  *Address;
      unsigned int  *LengthPtr;
   } ClientSocketNameItem;

#endif

#ifdef IP_NETLIB

   unsigned long  ClientNetLibSocket,
                  ServerNetLibSocket;

   struct SINDEF  ServerNetLibName,
                  ClientNetLibName;

   struct INADDRDEF NetLibAddressList [16];

   unsigned long  NetLibReturnedLength;
   struct dsc$descriptor  ClientInternetAddressDsc;
   struct dsc$descriptor  ServerHostNameDsc;
   struct dsc$descriptor  ServerInternetAddressDsc;

#endif

};

/***********************/
/* function prototypes */
/***********************/

#ifdef IP_UCX
   NetAccessDenied (unsigned short, char*, char*);
   NetDirectWrite (unsigned short, char*, int);
   NetDummyRead (unsigned short);
   NetDummyReadAst (unsigned short);
   NetShutdownSocketUcx (unsigned short, void*, boolean);
   NetCloseSocketUcx (unsigned short);
   NetTooBusy (unsigned short, char*, char*);
#endif

#ifdef IP_NETLIB
   NetAccessDenied (unsigned long*, char*, char*);
   NetDirectWrite (unsigned long*, char*, int);
   NetDummyRead (unsigned long*);
   NetDummyReadAst (unsigned long*);
   NetShutdownSocketNetLib (unsigned long*, void*, boolean);
   NetCloseSocketNetLib (unsigned long*);
   NetTooBusy (unsigned long*, char*, char*);
#endif

int NetWriteBuffered (struct RequestStruct*, void*, char*, int);
int NetWriteDefered (struct RequestStruct*, void*, char*, int);
int NetWriteDeferedBuffers (struct RequestStruct*);
NetAccept (struct ServiceStruct*);
NetAcceptAst (struct ServiceStruct*);
NetCreateService ();
NetGetService ();
NetGetServerHostName ();
NetHostLookup ();
NetListen ();
NetServerShutdown (unsigned short);
NetResponseHeaderAst (struct RequestStruct*);
NetShutdownSocket (struct RequestStruct*, void*, boolean);
NetCloseSocket (struct RequestStruct*);
int NetRead (struct RequestStruct*, void*, char*, int);
int NetWrite (struct RequestStruct*, void*, char*, int);

/*****************************************************************************/

